"""Validation of the AnuGA implementation of the shallow water wave equation.

This script sets up Okushiri Island benchmark as published at the

THE THIRD INTERNATIONAL WORKSHOP ON LONG-WAVE RUNUP MODELS
June 17-18 2004
Wrigley Marine Science Center
Catalina Island, California
http://www.cee.cornell.edu/longwave/


The validation data was downloaded and made available in this directory
for convenience but the original data is available at
http://www.cee.cornell.edu/longwave/index.cfm?page=benchmark&problem=2
where a detailed description of the problem is also available.


Run create_okushiri.py to process the boundary condition and build a the
mesh before running this script.


"""
# NOTE: Cache should be cleared before running this script


# Module imports
from anuga.shallow_water import Domain
from anuga.caching import cache
from anuga.fit_interpolate.fit import _fit_to_mesh
import project
import Numeric as num

internal_verbose = False # Verbose used in set_quantity and passed into fit_to_mesh

filename=project.bathymetry_filename
alpha=0.02
from anuga.config import points_file_block_line_size as max_read_lines

#-------------------------
# Create Domain from mesh
#-------------------------
domain = cache(Domain, (project.mesh_filename, {'verbose': True}), verbose=False)

# Clear caching of underlying function                                            
args = (filename, )
kwargs = {'vertex_coordinates': None,
          'triangles': None,
          'mesh': domain.mesh,
          'point_attributes': None,
          'alpha': alpha,
          'verbose': internal_verbose,
          'acceptable_overshoot': 1.01, # This is the default value in _fit_to_mesh
          'mesh_origin': None,
          'data_origin': None,
          'max_read_lines': max_read_lines,
          'attribute_name': None 
          }


cache(_fit_to_mesh,
      args, 
      kwargs,
      verbose=False,
      dependencies=[filename],
      clear=True)

# Check that cache is empty      
flag = cache(_fit_to_mesh,
             args, 
             kwargs,
             verbose=False,
             dependencies=[filename],
             test=True)
assert flag is None



#-------------------------
# Initial Conditions
#-------------------------
#print 'Set elevation and cache'
domain.set_quantity('elevation',
                    filename=filename,
                    alpha=0.02,                    
                    verbose=internal_verbose,
                    use_cache=True)
                    
ref = domain.get_quantity('elevation').get_values()                    

# Check that cache is now present (and correct)
flag = cache(_fit_to_mesh,
             args, 
             kwargs,
             verbose=False,
             dependencies=[filename],
             test=True)
assert flag is not None
res = domain.get_quantity('elevation').get_values()                                        
assert num.allclose(res, ref)

# Now check this using the high level call
#print 'Try to read in via cache'
domain.set_quantity('elevation',
                    filename=filename,
                    alpha=0.02,                    
                    verbose=internal_verbose,
                    use_cache=True)
                    
res = domain.get_quantity('elevation').get_values()                                        
assert num.allclose(res, ref)
